@@ -166,7 +166,7 @@ class BasicDataApi(object):
             try:
                 query = db_session.query(
                         FundNav
-                ).filter(    
+                ).filter(
                     FundNav.datetime >= start_date,
                     FundNav.datetime <= end_date,
                 ).delete(synchronize_session=False)
@@ -175,19 +175,21 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to delete data <err_msg> {e} from {FundNav.__tablename__}')
                 return None
-                
-    def get_fund_nav_with_date(self, start_date, end_date, fund_list):
+
+    def get_fund_nav_with_date(self, start_date, end_date, fund_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                         FundNav.fund_id,
                         FundNav.adjusted_net_value,
                         FundNav.datetime
-                    ).filter(
-                        FundNav.fund_id.in_(fund_list),
-                        FundNav.datetime >= start_date,
-                        FundNav.datetime <= end_date,
                     )
+                if fund_list:
+                    query = query.filter(FundNav.fund_id.in_(fund_list))
+                query = query.filter(
+                    FundNav.datetime >= start_date,
+                    FundNav.datetime <= end_date,
+                )
 
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
@@ -493,7 +495,7 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldAsset.__tablename__}')
                 return
-                
+
     def get_fund_hold_industry(self, dt) -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -506,7 +508,7 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldIndustry.__tablename__}')
                 return
-    
+
     def get_fund_hold_stock(self, dt) -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
@@ -519,7 +521,7 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
                 return
-    
+
     def get_fund_hold_bond(self, dt) -> pd.DataFrame:
        with BasicDatabaseConnector().managed_session() as db_session:
             try:
