@@ -373,19 +373,40 @@ class RawDataApi:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
 
-    def get_em_fund_scale(self, start_date, end_date):
+    def get_em_fund_scale(self, start_date: str = '', end_date: str = ''):
+        with RawDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                    EmFundScale.CODES,
+                    EmFundScale.DATES,
+                    EmFundScale.FUNDSCALE,
+                )
+                if start_date:
+                    query = query.filter(
+                        EmFundScale.DATES >= start_date,
+                    )
+                if end_date:
+                    query = query.filter(
+                        EmFundScale.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get scale data <err_msg> {e} from {EmFundScale.__tablename__}')
+                return None
+
+    def get_em_fund_status(self, end_date: str = ''):
         with RawDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                     EmFundScale
-                ).filter(
-                    EmFundScale.DATES >= start_date,
-                    EmFundScale.DATES <= end_date,
                 )
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
+                if end_date:
+                    query = query.filter(
+                        EmFundScale.DATES <= end_date,
+                    )
+                return pd.read_sql(query.statement, query.session.bind)
             except Exception as e:
-                print('Failed to get data <err_msg> {}'.format(e))
+                print(f'Failed to get data <err_msg> {e} from {EmFundScale.__tablename__}')
                 return None
 
     def get_em_stock_price(self, start_date: str, end_date: str, stock_list: Tuple[str] = (), columns: Tuple[str] = ()):
