@@ -378,11 +378,14 @@ class BasicDataPart1:
     def fund_size(self, start_date, end_date):
         try:
             # Since fund_size in basic db is latest snapshot, we only use end_date as param
-            df = RawDataApi().get_em_fund_scale(end_date, end_date)
-            df['fund_id'] = df.apply(
-                lambda x: self._data_helper._get_fund_id_from_order_book_id(x['CODES'].split('.')[0], x['DATES']), axis=1)
-            df = df.drop(['CODES', 'DATES'], axis = 1).rename(columns={'FUNDSCALE': 'latest_size'})
-            df = df[df['fund_id'].notnull()]
+            df = RawDataApi().get_em_fund_scale(end_date=end_date)
+            if df is None:
+                print('failed to get em fund scale for fund size')
+                return False
+            df = df.pivot_table(index='DATES', columns='CODES', values='FUNDSCALE').fillna(method='ffill')
+            df = df.iloc[[-1], :].apply(lambda x: pd.Series({'fund_id': self._data_helper._get_fund_id_from_order_book_id(x.name.split('.')[0], x.index.array[0]), 'latest_size': float(x.array[0])})).T
+            df = df.reset_index(drop=True)
+            df = df[df.notnull().all(axis=1)]
             self._data_helper._upload_basic(df, FundSize.__table__.name, to_truncate=True)
             return True
         except Exception as e:
