@@ -213,22 +213,40 @@ class EmRawDataDownloader:
             traceback.print_exc()
             return False
 
-    def em_fund_scale(self, start_date, end_date):
+    def em_fund_status(self, end_date: str):
         try:
-            # Get all fund ids, 功能函数-板块成分
-            # http://quantapi.eastmoney.com/Cmd/Sector?from=web
-            fund_id_result = c.sector('507013', end_date)
-            if fund_id_result.ErrorCode != 0:
-                print(f'Failed to get fund id list: {fund_id_result.ErrorMsg}')
-                return
+            fund_list = RawDataApi().get_em_fund_list(end_date, limit=1)
+            if fund_list is None:
+                print(f'failed to get fund list for fund status')
+                return False
+            fund_list = fund_list.all_live_fund_list.array[0]
+            data1 = c.css(fund_list, 'FUNDSCALE', f'EndDate={end_date},Ispandas=1')
+            if not isinstance(data1, pd.DataFrame):
+                if data1.ErrorCode != 0:
+                    print(f'failed to get fund status data1: {data1.ErrorMsg}')
+                return False
 
-            fund_id_list = fund_id_result.Codes
-            fund_id_str = ','.join(fund_id_list)
+            data2 = c.css(fund_list, 'PURCHSTATUS,REDEMSTATUS,LPLIMIT,OTCLPLIMIT,TRADESTATUS', f'TradeDate={end_date},Ispandas=1')
+            if not isinstance(data2, pd.DataFrame):
+                if data2.ErrorCode != 0:
+                    print(f'failed to get fund status datta2: {data2.ErrorMsg}')
+                return False
 
-            for d in self._get_date_list(start_date, end_date):
-                df = c.css(fund_id_str, 'FUNDSCALE', f'EndDate={d},Ispandas=1').reset_index()
-                df['DATES'] = d
-                self._data_helper._upload_raw(df, EmFundScale.__table__.name)
+            df = data1.drop(columns='DATES').join(data2.drop(columns='DATES'), how='outer')
+            df = df[df.notna().any(axis=1)]
+            if df.empty:
+                return True
+
+            df = df.reset_index()
+            df['DATES'] = end_date
+            df = df.astype({'FUNDSCALE': 'float64', 'LPLIMIT': 'float64', 'OTCLPLIMIT': 'float64'})
+            # 获取当前的fund status
+            now_df = RawDataApi().get_em_fund_status(end_date=end_date)
+            if now_df is not None:
+                # 过滤出来新增基金status以及旧基金的status发生变化的情况
+                df = df.merge(now_df.drop(columns=['_update_time']), how='left', on=['CODES', 'FUNDSCALE', 'LPLIMIT', 'OTCLPLIMIT', 'PURCHSTATUS', 'REDEMSTATUS', 'TRADESTATUS'], indicator=True, validate='one_to_many')
+                df = df[df._merge == 'left_only'].drop(columns=['_merge', 'DATES_y']).rename(columns={'DATES_x': 'DATES'})
+            self._data_helper._upload_raw(df, EmFundScale.__table__.name)
             return True
         except Exception as e:
             print(e)
@@ -1179,18 +1197,10 @@ class EmRawDataDownloader:
 
         df = RawDataApi().get_em_tradedates(start_date, end_date)
         for row in df.itertuples(index=False):
-            self.em_fund_benchmark(row.TRADEDATES, row.TRADEDATES, fund_list_result.Codes)
+            self.em_fund_benchmark(row.TRADEDATES, fund_list_result.Codes)
 
-    def em_fund_benchmark(self, start_date: str, end_date: str, fund_list: Tuple[str] = ()):
+    def em_fund_benchmark(self, end_date: str, fund_list):
         try:
-            api = RawDataApi()
-            if not fund_list:
-                # 如果没有基金列表就取最近的一条
-                fund_list_df = api.get_em_fund_list(end_date, limit=1)
-                if fund_list_df.shape[0] < 1:
-                    print(f"failed to get latest fund list, (date){end_date} (len){fund_list_df.shape[0]}")
-                    return False
-                fund_list = fund_list_df.iloc[0, :].all_live_fund_list.split(',')
             data = c.css(fund_list, 'BENCHMARK', f'EndDate={end_date},Ispandas=1')
             if not isinstance(data, pd.DataFrame):
                 if data.ErrorCode != 0:
@@ -1203,7 +1213,7 @@ class EmRawDataDownloader:
             df = data.reset_index().rename(columns=lambda x: EmFundBenchmark.__getattribute__(EmFundBenchmark, x).name)
             df['datetime'] = end_date
             # 获取当前的benchmark
-            now_df = api.get_em_fund_benchmark(end_date)
+            now_df = RawDataApi().get_em_fund_benchmark(end_date)
             if now_df is not None:
                 # 过滤出来新增基金benchmark以及旧基金的benchmark发生变化的情况
                 df = df.merge(now_df.drop(columns=['_update_time']), how='left', on=['em_id', 'benchmark'], indicator=True, validate='one_to_one')
@@ -1268,10 +1278,15 @@ class EmRawDataDownloader:
         for dt in dt_list:
             _res = [] 
             for rank in rank_list:
-                data=c.css(all_fund,"PRTKEYSTOCKNAME,PRTKEYSTOCKVALUE,PRTKEYSTOCKTONAV",f"ReportDate={dt},Rank={rank},Ispandas=1")
-                data = data.rename(columns={'PRTKEYSTOCKNAME':f'rank{rank}_stock','PRTKEYSTOCKVALUE':f'rank{rank}_stockval','PRTKEYSTOCKTONAV':f'rank{rank}_stockweight'})
+                data=c.css(all_fund,"PRTKEYSTOCKNAME,PRTKEYSTOCKCODE,PRTKEYSTOCKVALUE,PRTKEYSTOCKTONAV",f"ReportDate={dt},Rank={rank},Ispandas=1")
+                data = data.rename(columns={'PRTKEYSTOCKNAME': f'rank{rank}_stock',
+                                            'PRTKEYSTOCKCODE': f'rank{rank}_stock_code',
+                                            'PRTKEYSTOCKVALUE': f'rank{rank}_stockval',
+                                            'PRTKEYSTOCKTONAV': f'rank{rank}_stockweight',
+                                            })
                 data = data.drop('DATES',axis=1)
                 _res.append(data)
+                print(f'[em_fund_stock] {dt} rank {rank} done')
             df = pd.concat(_res,axis=1)
             df['DATES'] = dt
             res.append(df)
@@ -1305,8 +1320,9 @@ class EmRawDataDownloader:
             failed_tasks.append('em_tradedates')
             return failed_tasks
 
-        if not self.em_fund_scale(start_date, end_date):
-            failed_tasks.append('em_fund_scale')
+        # could only update the end_date's data
+        if not self.em_fund_status(end_date):
+            failed_tasks.append('em_fund_status')
 
         if not self.em_fund_nav(start_date, end_date):
             failed_tasks.append('em_fund_nav')
@@ -1350,14 +1366,14 @@ class EmRawDataDownloader:
                     failed_tasks.append('em_fund_info')
                 if not self.em_fund_fee(new_fund_list):
                     failed_tasks.append('em_fund_fee')
+                # if not self.em_fund_benchmark(end_date, new_fund_list):
+                #     failed_task.append('em_fund_benchmark')
 
         if not self.em_macroeconomic_price(start_date, end_date):
             failed_tasks.append('em_macroeconomic_price')
 
         if not self.em_fund_rate(end_date):
             failed_tasks.append('em_fund_rate')
-        # if not self.em_fund_benchmark(start_date, end_date):
-        #     failed_task.append('em_fund_benchmark')
 
         return failed_tasks
 
@@ -1379,7 +1395,7 @@ if __name__ == '__main__':
     # em.em_stock_daily_info_history('./')
     # em.em_stock_refinancing('20170101', '20181231')
     # em.add_columns_to_fin_fac('20190930')
-    # em.em_fund_scale('20200513', '20200513')
+    # em.em_fund_status('20200513', '20200513')
     # em.em_index_component('20200528', '20200529')
     # em.em_fund_list('20200702', '20200702')
     # em.em_fund_info_history('20200707')
