@@ -35,7 +35,15 @@ class FundDailyCollectionProcessor(object):
             if not x:
                 return None
             x = json.loads(x)
-            return max(x, key=x.get)
+
+            # 特殊常数处理
+            if x.get('1'):
+                return None
+
+            select = max(x, key=x.get)
+            if x[select] >= 0.8:
+                return select
+            return None
 
         def get_index_name(x, index_df):
             if not x:
@@ -291,12 +299,27 @@ class FundDailyCollectionProcessor(object):
             return None
         return round((pd.datetime.now().date() - x).days / 365, 2)
 
+    def calc_ret_rank(self, df, cols):
+        for col in cols:
+            df[col + '_rank'] = df[col].rank(method='min', ascending=False)
+        return df
+
+    def calc_group_num(self, df):
+        df['group_num'] = len(df)
+        return df
+
     def modify_fund_manager(self, x):
         try:
             return x.split('\r\n')[-1].split('(')[0]
         except:
             return x
 
+    def select_benchmark(self, x):
+        if x['wind_class_II'] not in ('被动指数型基金', '增强指数型基金'):
+            x['benchmark_s'] = None
+            x['benchmark_name'] = None
+        return x
+
     def compute_daily_collection(self):
         try:
             funds = self.get_fund_df()
@@ -368,11 +391,28 @@ class FundDailyCollectionProcessor(object):
                 'company_id': 'company_name',
                 'desc_name': 'symbol',
             })
+            df = df.groupby('wind_class_II').apply(self.calc_ret_rank, cols=[
+                'last_week_return',
+                'last_month_return',
+                'last_three_month_return',
+                'last_six_month_return',
+                'last_twelve_month_return',
+                'y3_ret',
+                'y5_ret',
+                'year_to_date_return',
+                'to_date_return',
+            ])
+            df = df.groupby('wind_class_II').apply(self.calc_group_num)
+
+            print(df)
+            df = df.apply(self.select_benchmark, axis=1)
+            print(df)
             df = df.drop(['redeem_status', 'subscribe_status'], axis=1)
             df = df.sort_values(['fund_id'])
             df = df.drop_duplicates(subset=['order_book_id'], keep='first')
             df = df.dropna(subset=['order_book_id'])
 
+
             # df.to_csv('./hhh.csv')
             self.append_data(FundDailyCollection.__tablename__, df)
 
