@@ -2,7 +2,7 @@ import pandas as pd
 import traceback
 from ...wrapper.mysql import DerivedDatabaseConnector, BasicDatabaseConnector, ViewDatabaseConnector
 from ...view.view_models import IndexDailyCollection
-from ...view.basic_models import IndexInfo, IndexPrice
+from ...view.basic_models import IndexInfo, IndexPrice, IndexComponent
 from ...view.derived_models import IndexValuation, IndexReturn, IndexVolatility
 
 class IndexDailyCollectionProcessor(object):
@@ -106,6 +106,21 @@ class IndexDailyCollectionProcessor(object):
             except Exception as e:
                 print('Failed get_index_info<err_msg> {}'.format(e))
 
+    def get_index_component(self):
+        with BasicDatabaseConnector().managed_session() as mn_session:
+            try:
+                query = mn_session.query(
+                    IndexComponent.index_id,
+                    IndexComponent.id_cat,
+                )
+                df = pd.read_sql(query.statement, query.session.bind)
+                df['id_cat'] = df['id_cat'].apply(lambda x: x.name)
+                df = df.set_index('index_id')
+                return df
+
+            except Exception as e:
+                print('Failed get_index_info<err_msg> {}'.format(e))
+
     def get_index_price(self):
         with BasicDatabaseConnector().managed_session() as mn_session:
             try:
@@ -152,9 +167,10 @@ class IndexDailyCollectionProcessor(object):
             ret = self.get_index_return()
             val = self.get_index_valuation()
             price = self.get_index_price()
+            component = self.get_index_component()
 
             print('2、 concat data...')
-            df = pd.concat([info, vol, ret, val, price], axis=1, sort=False)
+            df = pd.concat([info, vol, ret, val, price, component], axis=1, sort=False)
             df.index.name = 'index_id'
             df = df.reset_index()
 
