@@ -108,7 +108,7 @@ class TianCollectionProcessor():
         info_data_list: List[str] = ['name', 'bl_em_ind_code']
         price_data_list: List[str] = ['close']
         daily_data_list: List[str] = ['total_share', 'hold_frozen_amt_accum_ratio',
-                                      'asset_mrq', 'equity_mrq', 'pe_ttm_deducted', 'pb_lyr_n', 'ps_ttm', 'a_holder']
+                                      'pe_ttm_deducted', 'pb_lyr_n', 'ps_ttm', 'a_holder']
         fin_data_list: List[str] = ['np_ttmrp', 'performance_express_parent_ni', 'mb_sales_cons', 'mb_sales_cons_p', 'gp_margin', 'np_margin',
                                     'inv_turn_ratio', 'ar_turn_ratio', 'expense_toor', 'roe_avg', 'roe_wa', 'eps_basic', 'eps_diluted', 'bps',
                                     'balance_statement_25', 'balance_statement_46', 'balance_statement_93', 'balance_statement_103',
