@@ -49,7 +49,7 @@ class AssetWeight(AssetDict):
     def rebalance(self):
         _sum = 0.0
         for k, v in self.__dict__.items():
-            assert round(v,8) >= 0, f'{k} has negative value'
+            assert round(v,6) >= 0, f'{k} {v} has negative value'
             _sum += v
         assert _sum > 0, 'param sum value must be positive'
         # normalize, make sure change is correct
@@ -185,12 +185,7 @@ class FundPosItem:
             self.volume = volume
             self.avg_cost = amt / volume
         else:
-            if trade.is_to_cleanup:
-                trade.volume = self.volume
-                trade.amount = trade.volume * p
-                self.volume = 0
-            else:
-                self.volume = volume
+            self.volume -= trade.volume
             if self.volume < 1e-8:# 清空仓位 平均成本为0
                 self.avg_cost = 0
             else: #非清仓卖出 平均成本不变
@@ -422,8 +417,8 @@ class FundPosition:
 
         p = trade.trade_date if trade.trade_price else trade.mark_price
         amt = trade.amount if trade.amount else trade.volume * p
-        cash_left = self.cash + (-amt if trade.is_buy else amt) 
-        if cash_left <= -1e-8:
+        cash_left = self.cash + (-amt if trade.is_buy else amt)
+        if cash_left <= -1e-6:
             print(f'cash negative alert: cancel order due to cash negative trade: {trade}, cash left if trade successed: {cash_left}')
             return False
         if pos_item.update(trade):
