@@ -129,9 +129,9 @@ class FundInfo(Base):
     benchmark_1 = Column(CHAR(255)) # 业绩基准标的指数简称第一名
     benchmark_2 = Column(CHAR(255)) # 业绩基准标的指数简称第二名
     index_id = Column(CHAR(20)) # 基于第一业绩标准所标注的指数ID
-    is_c =  Column("is_c", BOOLEAN, nullable=False)  #是否是etf  0 非  1 c  
-    is_a = Column("is_a", BOOLEAN, nullable=False)  #是否是etf  0 非  1 a   
-    ac_filter = Column("ac_filter", BOOLEAN, nullable=False) #是否ac均有要排除的a 0 排除  1 保留  
+    is_c =  Column("is_c", BOOLEAN, nullable=False)  #是否是etf  0 非  1 c
+    is_a = Column("is_a", BOOLEAN, nullable=False)  #是否是etf  0 非  1 a
+    ac_filter = Column("ac_filter", BOOLEAN, nullable=False) #是否ac均有要排除的a 0 排除  1 保留
     is_selected_mmf = Column(TINYINT(1)) # 是否基金规模最大的前50只货币基金(10年前有两只存在)  0 非  1 是
     national_debt_extension = Column(TINYINT(1)) # 纯债tag  0 非  1 是
     index_id_new = Column(CHAR(20)) # 基于第一业绩标准所标注的指数ID新
@@ -175,7 +175,7 @@ class FundNav(Base):
     datetime = Column(DATE, primary_key=True) # 日期
 
     unit_net_value = Column(DOUBLE(asdecimal=False)) # 单位净值
-    acc_net_value = Column(DOUBLE(asdecimal=False)) # 累积单位净值 基金公司公告发布的原始数据 单位净值 + 单位累积分红
+    acc_net_value = Column(DOUBLE(asdecimal=False)) # 累计单位净值 基金公司公告发布的原始数据 单位净值 + 单位累计分红
     adjusted_net_value = Column(DOUBLE(asdecimal=False)) # 复权净值 考虑分红再投资后调整的单位净值
     change_rate = Column(DOUBLE(asdecimal=False)) # 涨跌幅
     daily_profit = Column(DOUBLE(asdecimal=False)) # 每万元收益（日结型货币基金专用）
@@ -299,8 +299,8 @@ class Fund_size_and_hold_rate(Base):
     fund_id = Column(CHAR(10), primary_key=True)  # 基金id
     datetime = Column(DATE, primary_key=True)  # 日期
     size = Column(DOUBLE(asdecimal=False)) # 最新规模
-    personal_holds = Column(DOUBLE(asdecimal=False)) # 个人持有比例 单位百分比 
-    institution_holds = Column(DOUBLE(asdecimal=False)) # 机构持有比例 单位百分比 
+    personal_holds = Column(DOUBLE(asdecimal=False)) # 个人持有比例 单位百分比
+    institution_holds = Column(DOUBLE(asdecimal=False)) # 机构持有比例 单位百分比
 
 class FundRate(Base):
     '''基金评级'''
@@ -316,7 +316,7 @@ class FundRate(Base):
     tx_comp = Column(CHAR(5)) # 天相投顾综合评级
     sh_3y_comp = Column(CHAR(5)) #上海证券3年评级(综合评级)
     sh_3y_stock = Column(CHAR(5)) #上海证券3年评级(选股能力)
-    sh_3y_timeret = Column(CHAR(5)) #上海证券3年评级(择时能力) 
+    sh_3y_timeret = Column(CHAR(5)) #上海证券3年评级(择时能力)
     sh_3y_sharpe = Column(CHAR(5)) #上海证券3年评级(夏普比率)
     sh_5y_comp = Column(CHAR(5)) #上海证券5年评级(综合评级)
     sh_5y_stock = Column(CHAR(5)) #上海证券5年评级(选股能力)
@@ -329,7 +329,7 @@ class FundRate(Base):
     jian_stock = Column(CHAR(5)) #济安金信基金评级(选股能力)
     jian_timeret = Column(CHAR(5)) #济安金信基金评级(择时能力)
     jian_track = Column(CHAR(5)) #济安金信基金评级(基准跟踪能力)
-    jian_alpha = Column(CHAR(5)) #济安金信基金评级(超额收益能力) 
+    jian_alpha = Column(CHAR(5)) #济安金信基金评级(超额收益能力)
     jian_fee = Column(CHAR(5)) #济安金信基金评级(整体费用)
 
 class FundHoldAsset(Base):
@@ -348,7 +348,7 @@ class FundHoldIndustry(Base):
     '''基金持仓前三行业'''
 
     __tablename__ = 'fund_hold_industry'
-    
+
     fund_id = Column(CHAR(10), primary_key=True) # 基金ID
     datetime = Column(DATE, primary_key=True) # 日期
     rank1_indname = Column(CHAR(50)) #第一排名行业名称
@@ -366,33 +366,43 @@ class FundHoldStock(Base):
     fund_id = Column(CHAR(10), primary_key=True) # 基金ID
     datetime = Column(DATE, primary_key=True) # 日期
     rank1_stock = Column(CHAR(20)) #股票名
+    rank1_stock_code = Column(CHAR(16))  # 股票ID
     rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank2_stock = Column(CHAR(20)) #股票名
+    rank2_stock_code = Column(CHAR(16))  # 股票ID
     rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank3_stock = Column(CHAR(20)) #股票名
+    rank3_stock_code = Column(CHAR(16))  # 股票ID
     rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank4_stock = Column(CHAR(20)) #股票名
+    rank4_stock_code = Column(CHAR(16))  # 股票ID
     rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank5_stock = Column(CHAR(20)) #股票名
+    rank5_stock_code = Column(CHAR(16))  # 股票ID
     rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank6_stock = Column(CHAR(20)) #股票名
+    rank6_stock_code = Column(CHAR(16))  # 股票ID
     rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank7_stock = Column(CHAR(20)) #股票名
+    rank7_stock_code = Column(CHAR(16))  # 股票ID
     rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank8_stock = Column(CHAR(20)) #股票名
+    rank8_stock_code = Column(CHAR(16))  # 股票ID
     rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank9_stock = Column(CHAR(20)) #股票名
+    rank9_stock_code = Column(CHAR(16))  # 股票ID
     rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank10_stock = Column(CHAR(20)) #股票名
+    rank10_stock_code = Column(CHAR(16))  # 股票ID
     rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
