@@ -211,6 +211,43 @@ class FundScore(Base):
     )
 
 
+class FundScoreExtended(Base):
+    '''基金评分(新)'''
+
+    __tablename__ = 'fund_score_extended'
+
+    fund_id = Column(CHAR(16), primary_key=True)  # 基金代码
+    datetime = Column(DATE, primary_key=True)  # 日期
+    wind_class_1 = Column(CHAR(64))  # Wind基金类型
+    ret = Column(DOUBLE(asdecimal=False), nullable=False)  # ret
+    vol = Column(DOUBLE(asdecimal=False), nullable=False)  # volatility
+    sr = Column(DOUBLE(asdecimal=False))  # sharpe ratio
+    ir = Column(DOUBLE(asdecimal=False))  # information ratio
+    beta = Column(DOUBLE(asdecimal=False))  # beta
+    alpha = Column(DOUBLE(asdecimal=False))  # alpha
+    mdd = Column(DOUBLE(asdecimal=False), nullable=False)  # max drawdown
+    timing = Column(DOUBLE(asdecimal=False))  # timing
+    ret_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of ret
+    vol_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of volatility
+    sr_score = Column(DOUBLE(asdecimal=False))  # score of sharpe ratio
+    ir_score = Column(DOUBLE(asdecimal=False))  # score of information ratio
+    beta_score = Column(DOUBLE(asdecimal=False))  # score of beta
+    alpha_score = Column(DOUBLE(asdecimal=False))  # score of alpha
+    mdd_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of max drawdown
+    return_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of return
+    robust_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of robust
+    timing_score = Column(DOUBLE(asdecimal=False))  # score of timing
+    return_rank = Column(DOUBLE(asdecimal=False), nullable=False)  # rank of return
+    robust_rank = Column(DOUBLE(asdecimal=False), nullable=False)  # rank of robust
+    timing_rank = Column(DOUBLE(asdecimal=False))  # rank of timing
+    total_score = Column(DOUBLE(asdecimal=False), nullable=False)  # score of total
+    total_rank = Column(DOUBLE(asdecimal=False), nullable=False)  # rank of total
+
+    __table_args__ = (
+        Index('idx_fund_score_extended_datetime', 'datetime'),
+    )
+
+
 class AssetAllocationInfo(Base):
     '''十档大类资产组合'''
 
