@@ -422,10 +422,16 @@ class EmFundScale(Base):
     '''
 
     __tablename__ = 'em_fund_scale'
-    CODES = Column(CHAR(10), primary_key=True) # 合约代码
-    DATES = Column(DATE, primary_key=True) # 日期
 
-    FUNDSCALE = Column(DOUBLE(asdecimal=False)) # 基金规模
+    CODES = Column(CHAR(10), primary_key=True)  # 合约代码
+    DATES = Column(DATE, primary_key=True)  # 日期
+
+    FUNDSCALE = Column(DOUBLE(asdecimal=False))  # 基金规模
+    PURCHSTATUS = Column(CHAR(16))  # 申购状态
+    REDEMSTATUS = Column(CHAR(16))  # 赎回状态
+    LPLIMIT = Column(DOUBLE(asdecimal=False))  # 暂停大额申购上限
+    OTCLPLIMIT = Column(DOUBLE(asdecimal=False))  # 场外暂停大额申购上限
+    TRADESTATUS = Column(CHAR(16))  # 交易状态
 
 
 class EMIndexPct(Base):
@@ -605,19 +611,22 @@ class EmStockFinFac(Base):
     BPS = Column('bps', DOUBLE(asdecimal=False)) # 每股净资产
     BALANCESTATEMENT_25 = Column('balance_statement_25', DOUBLE(asdecimal=False)) # 流动资产合计
     BALANCESTATEMENT_46 = Column('balance_statement_46', DOUBLE(asdecimal=False)) # 非流动资产合计
+    BALANCESTATEMENT_74 = Column('balance_statement_74', DOUBLE(asdecimal=False)) # 资产总计
     BALANCESTATEMENT_93 = Column('balance_statement_93', DOUBLE(asdecimal=False)) # 流动负债合计
     BALANCESTATEMENT_103 = Column('balance_statement_103', DOUBLE(asdecimal=False)) # 非流动负债合计
-    BALANCESTATEMENT_141 = Column('balance_statement_141', DOUBLE(asdecimal=False)) # 股东权益合计
+    BALANCESTATEMENT_128 = Column('balance_statement_128', DOUBLE(asdecimal=False)) # 负债合计
     BALANCESTATEMENT_140 = Column('balance_statement_140', DOUBLE(asdecimal=False)) # 归属于母公司股东权益合计
+    BALANCESTATEMENT_141 = Column('balance_statement_141', DOUBLE(asdecimal=False)) # 股东权益合计
     BALANCESTATEMENT_195 = Column('balance_statement_195', DOUBLE(asdecimal=False)) # 其他权益工具
+    BALANCESTATEMENT_196 = Column('balance_statement_196', DOUBLE(asdecimal=False)) # 其中:优先股(其他权益工具)
     INCOMESTATEMENT_9 = Column('income_statement_9', DOUBLE(asdecimal=False)) # 营业收入
+    INCOMESTATEMENT_14 = Column('income_statement_14', DOUBLE(asdecimal=False)) # 财务费用
     INCOMESTATEMENT_48 = Column('income_statement_48', DOUBLE(asdecimal=False)) # 营业利润
     INCOMESTATEMENT_60 = Column('income_statement_60', DOUBLE(asdecimal=False)) # 净利润
     INCOMESTATEMENT_61 = Column('income_statement_61', DOUBLE(asdecimal=False)) # 归属于母公司股东的净利润
     INCOMESTATEMENT_83 = Column('income_statement_83', DOUBLE(asdecimal=False)) # 营业总收入
     INCOMESTATEMENT_85 = Column('income_statement_85', DOUBLE(asdecimal=False)) # 其他业务收入
     INCOMESTATEMENT_127 = Column('income_statement_127', DOUBLE(asdecimal=False)) # 利息费用
-    INCOMESTATEMENT_14 = Column('income_statement_14', DOUBLE(asdecimal=False)) # 财务费用
     CASHFLOWSTATEMENT_39 = Column('cashflow_statement_39', DOUBLE(asdecimal=False)) # 经营活动产生的现金流量净额
     CASHFLOWSTATEMENT_59 = Column('cashflow_statement_59', DOUBLE(asdecimal=False)) # 投资活动产生的现金流量净额
     CASHFLOWSTATEMENT_77 = Column('cashflow_statement_77', DOUBLE(asdecimal=False)) # 筹资活动产生的现金流量净额
@@ -773,7 +782,7 @@ class WindFundHolderStructure(Base):
     '''万德静态数据 中国共同基金持有人结构'''
 
     __tablename__ = 'wind_fund_holder_structure'
-    
+
     END_DT = Column(CHAR(8), primary_key=True)  # 日期
     S_INFO_WINDCODE = Column(CHAR(20), primary_key=True)  # wind id
     SEC_ID = Column(CHAR(15))  # 证券id
@@ -809,7 +818,7 @@ class WindFundStockPortfolio(Base):
     F_PRT_POSSTKTONAV = Column(DOUBLE(asdecimal=False)) # 积极投资持有股票市值占净资产比例
     F_PRT_PASSTKEVALUE = Column(DOUBLE(asdecimal=False)) # 指数投资持有股票市值 元
     F_PRT_PASSTKQUANTITY = Column(DOUBLE(asdecimal=False)) # 指数投资持有股数 股
-    F_PRT_PASSTKTONAV = Column(DOUBLE(asdecimal=False)) # 指数投资持有股票市值占净资产比例 
+    F_PRT_PASSTKTONAV = Column(DOUBLE(asdecimal=False)) # 指数投资持有股票市值占净资产比例
     ANN_DATE = Column(CHAR(8))  # 公告日期
     STOCK_PER = Column(DOUBLE(asdecimal=False)) # 占股票市值比
     FLOAT_SHR_PER = Column(DOUBLE(asdecimal=False)) # 占流通股本比例
@@ -823,8 +832,8 @@ class WindFundNav(Base):
     PRICE_DATE = Column(CHAR(8), primary_key=True)  # 日期
     ANN_DATE = Column(CHAR(8))  # 公告日期
     F_NAV_UNIT = Column(DOUBLE(asdecimal=False)) # 单位净值
-    F_NAV_ACCUMULATED = Column(DOUBLE(asdecimal=False)) # 累积净值
-    F_NAV_DIVACCUMULATED = Column(DOUBLE(asdecimal=False)) # 累积分红
+    F_NAV_ACCUMULATED = Column(DOUBLE(asdecimal=False)) # 累计净值
+    F_NAV_DIVACCUMULATED = Column(DOUBLE(asdecimal=False)) # 累计分红
     F_NAV_ADJFACTOR = Column(DOUBLE(asdecimal=False)) # 复权因子
     CRNCY_CODE = Column(CHAR(5)) # 货币
     F_PRT_NETASSET = Column(DOUBLE(asdecimal=False)) # 资产净值
@@ -832,7 +841,7 @@ class WindFundNav(Base):
     NETASSET_TOTAL = Column(DOUBLE(asdecimal=False)) # 合计资产净值
     F_NAV_ADJUSTED = Column(DOUBLE(asdecimal=False)) # 复权单位净值
     IS_EXDIVIDENDDATE = Column(DOUBLE(asdecimal=False)) # 是否净值除权日
-    F_NAV_DISTRIBUTION = Column(DOUBLE(asdecimal=False)) # 累积单位分配
+    F_NAV_DISTRIBUTION = Column(DOUBLE(asdecimal=False)) # 累计单位分配
 
 class WindFundManager(Base):
     '''万德静态数据 中国共同基金基金经理表'''
@@ -848,7 +857,7 @@ class WindFundManager(Base):
     F_INFO_MANAGER_EDUCATION = Column(CHAR(10)) # 学历
     F_INFO_MANAGER_NATIONALITY = Column(CHAR(10)) # 国籍
     F_INFO_MANAGER_STARTDATE = Column(CHAR(8)) # 任职日期
-    F_INFO_MANAGER_LEAVEDATE = Column(CHAR(8)) # 离职日期 
+    F_INFO_MANAGER_LEAVEDATE = Column(CHAR(8)) # 离职日期
     F_INFO_MANAGER_RESUME = Column(TEXT) # 简历
     S_INFO_MANAGER_POST = Column(CHAR(255)) # 备注（对于特殊基金经理的备注）
     F_INFO_ESCROW_FUNDMANAGER = Column(CHAR(20)) # 代管基金经理
@@ -885,14 +894,14 @@ class FundBenchmark(Base):
     index_text = Column(TEXT, nullable=False)  # 业绩比较基准
     benchmark = Column(TEXT, nullable=False)  # 解析出来的业绩比较基准
     assets = Column(CHAR(32))  # 追踪的标的
-    industry = Column(CHAR(64))  # 行业分类 
+    industry = Column(CHAR(64))  # 行业分类
 
 
 class EMFundRate(Base):
     '''东财基金评级'''
 
     __tablename__ = 'em_fund_rate'
-    
+
     CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
     DATES = Column(DATE, primary_key=True) # 日期
     MKTCOMPRE3YRAT = Column(CHAR(15)) # 市场综合3年评级
@@ -902,16 +911,16 @@ class EMFundRate(Base):
     TXCOMRATRAT = Column(CHAR(15)) # 天相投顾综合评级
     SHSTOCKSTAR3YCOMRAT = Column(CHAR(15)) #上海证券3年评级(综合评级)
     SHSTOCKSTAR3YSTOCKRAT = Column(CHAR(15)) #上海证券3年评级(选证能力)
-    SHSTOCKSTAR3YTIMERAT = Column(CHAR(15)) # 上海证券3年评级(择时能力) 
+    SHSTOCKSTAR3YTIMERAT = Column(CHAR(15)) # 上海证券3年评级(择时能力)
     SHSTOCKSTAR3YSHARPERAT = Column(CHAR(15)) # 上海证券3年评级(夏普比率)
-    SHSTOCKSTAR5YCOMRATRAT = Column(CHAR(15)) # 上海证券5年评级(综合评级) 
+    SHSTOCKSTAR5YCOMRATRAT = Column(CHAR(15)) # 上海证券5年评级(综合评级)
     SHSTOCKSTAR5YSTOCKRAT = Column(CHAR(15)) # 上海证券5年评级(选证能力)
-    SHSTOCKSTAR5YTIMERAT = Column(CHAR(15)) # 上海证券5年评级(择时能力) 
+    SHSTOCKSTAR5YTIMERAT = Column(CHAR(15)) # 上海证券5年评级(择时能力)
     SHSTOCKSTAR5YSHARPRAT = Column(CHAR(15)) # 上海证券5年评级(夏普比率)
     JAJXCOMRAT = Column(CHAR(15)) # 济安金信基金评级(综合评级)
     JAJXEARNINGPOWERRAT = Column(CHAR(15)) # 济安金信基金评级(盈利能力)
     JAJXACHIEVESTABILITYRAT = Column(CHAR(15)) # 济安金信基金评级(业绩稳定性)
-    JAJXANTIRISKRAT = Column(CHAR(15)) # 济安金信基金评级(抗风险能力) 
+    JAJXANTIRISKRAT = Column(CHAR(15)) # 济安金信基金评级(抗风险能力)
     JAJXSTOCKSELECTIONRAT = Column(CHAR(15)) # 济安金信基金评级(选股能力)
     JAJXTIMESELECTIONRAT = Column(CHAR(15)) # 济安金信基金评级(择时能力)
     JAJXBENCHMARKTRACKINGRAT = Column(CHAR(15)) # 济安金信基金评级(基准跟踪能力)
@@ -925,9 +934,9 @@ class EMFundHoldAsset(Base):
 
     CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
     DATES = Column(DATE, primary_key=True) # 日期
-    PRTSTOCKTONAV = Column(DOUBLE(asdecimal=False))#股票市值占基金资产净值比 
-    PRTBONDTONAV = Column(DOUBLE(asdecimal=False))#债券市值占基金资产净值比 
-    PRTCASHTONAV = Column(DOUBLE(asdecimal=False))#银行存款占基金资产净值比 
+    PRTSTOCKTONAV = Column(DOUBLE(asdecimal=False))#股票市值占基金资产净值比
+    PRTBONDTONAV = Column(DOUBLE(asdecimal=False))#债券市值占基金资产净值比
+    PRTCASHTONAV = Column(DOUBLE(asdecimal=False))#银行存款占基金资产净值比
     PRTOTHERTONAV = Column(DOUBLE(asdecimal=False))#其他资产占基金资产净值比
 
 class EMFundHoldIndustry(Base):
@@ -948,36 +957,47 @@ class EMFundHoldStock(Base):
     '''东财基金重仓股'''
 
     __tablename__ = 'em_fund_stock'
+
     CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
     DATES = Column(DATE, primary_key=True) # 日期
     rank1_stock = Column(CHAR(20)) #股票名
+    rank1_stock_code = Column(CHAR(16))  # 股票ID
     rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank2_stock = Column(CHAR(20)) #股票名
+    rank2_stock_code = Column(CHAR(16))  # 股票ID
     rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank3_stock = Column(CHAR(20)) #股票名
+    rank3_stock_code = Column(CHAR(16))  # 股票ID
     rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank4_stock = Column(CHAR(20)) #股票名
+    rank4_stock_code = Column(CHAR(16))  # 股票ID
     rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank5_stock = Column(CHAR(20)) #股票名
+    rank5_stock_code = Column(CHAR(16))  # 股票ID
     rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank6_stock = Column(CHAR(20)) #股票名
+    rank6_stock_code = Column(CHAR(16))  # 股票ID
     rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank7_stock = Column(CHAR(20)) #股票名
+    rank7_stock_code = Column(CHAR(16))  # 股票ID
     rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank8_stock = Column(CHAR(20)) #股票名
+    rank8_stock_code = Column(CHAR(16))  # 股票ID
     rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank9_stock = Column(CHAR(20)) #股票名
+    rank9_stock_code = Column(CHAR(16))  # 股票ID
     rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
     rank10_stock = Column(CHAR(20)) #股票名
+    rank10_stock_code = Column(CHAR(16))  # 股票ID
     rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
     rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
 
