@@ -50,6 +50,7 @@ class ReportHelper:
         self.taa_params = taa_helper.params if isinstance(taa_helper, TAAHelper) else None
         self.index_pct = dm.dts.index_pct
         self.dts = dm.dts.trading_days.datetime
+        self.fund_score_dm = dm._score_manager.score_cache
         trade_list = []
         for d, trade_d in self.trade_history.items():
             trade_d = [_.__dict__ for _ in trade_d]
@@ -320,7 +321,7 @@ class ReportHelper:
         #     FundPainter.plot_turnover_rate_each_year(self.turnover_df, self.turnover_rate_yearly_avg)
 
     def asset_price_ratio(self):    
-        return HybridPainter.plot_fund_alpha(self.fund_nav, self.fund_info, self.index_price, self.fund_position_history.copy(), self.get_fund_stat(), self.dts)
+        return HybridPainter.plot_asset_price_ratio(self.fund_nav, self.fund_info, self.index_price, self.fund_score_dm, self.get_fund_stat(), self.dts, self.saa_weight)
         
     def plot_whole(self):
         self.backtest_fund_plot()
