@@ -65,6 +65,16 @@ class AssetTrader(Helper):
             new_position = cur_position.copy()
             for trd in trades:
                 new_position.update(trd)
+            #如果一个交易单过小，不达到交易下限，会被忽略，导致买单和卖单交易额相加不相等
+            buy_trades_amt = sum([i.amount for i in trades if i.is_buy is True])
+            sell_trades_amt = sum([i.mark_price * i.volume for i in trades if i.is_buy is False]) 
+            buy_adjusted = sell_trades_amt / buy_trades_amt if sell_trades_amt > 0 else 1
+            for trd in trades:
+                if trd.is_buy == True:
+                    trd.amount *= buy_adjusted
+            # buy_trades_amt = sum([i.amount for i in trades if i.is_buy is True])
+            # sell_trades_amt = sum([i.mark_price * i.volume for i in trades if i.is_buy is False]) 
+            # print(f' compare trades amt buy {buy_trades_amt} and sell {sell_trades_amt} diff {buy_trades_amt-sell_trades_amt }')
             return new_position, trades
 
     def finalize_trade(self, dt, trades: list,
@@ -74,11 +84,7 @@ class AssetTrader(Helper):
         traded_list = []
         if trades is None or len(trades) == 0:
             return pendings, traded_list
-        # TODO: if some trades needs more time
         for trd in trades:
-            # TODO: commision calculate
-            #trd.commission = ?
-            # update position
             trd.trade_price = t1_price.__dict__[trd.index_id]
             trd.volume = trd.volume if trd.volume else (trd.amount / trd.trade_price)
             trd.trade_date = dt
@@ -87,13 +93,29 @@ class AssetTrader(Helper):
                     #print(f'trade volume exceeds, adjusted to pos (index_id){trd.index_id} (vol){trd.volume} (is_buy){trd.is_buy} (pos){bt_position.__dict__[trd.index_id]}')
                     trd.volume = bt_position.__dict__[trd.index_id]
             trd.amount = trd.volume * trd.trade_price    
+            if self.asset_param.EnableCommission:
+                if not trd.is_buy:
+                    trd.commission = trd.amount * self.asset_param.RedeemDiscount * self.asset_param.AssetRedeemRate[trd.index_id]
+                    trd.amount -= trd.commission
+
+        _trade_list_buy = [i  for i in trades if i.is_buy is True]
+        _trade_list_sel = [i  for i in trades if i.is_buy is False]
+        # 买单按照amount下单， 不会出现计划资金和实际资金不符合情况
+        # 卖单按照volume下单， 会出现计算资金和实际资金不符合情况
+        # 保证卖单和买单实际成交的金额一致，就不会出现现金比例波动的情况，现金就可以设置为0，去掉现金资产比例 
+        plan_sel_amount = 0 if len(_trade_list_sel) < 1 else sum([i.amount for i in _trade_list_sel])
+        plan_buy_amount = 0 if len(_trade_list_buy) < 1 else sum([i.amount for i in _trade_list_buy])
+        if plan_sel_amount == 0: 
+            buy_amount_adjusted_rate = 1
+        else:
+            buy_amount_adjusted_rate = plan_sel_amount / plan_buy_amount
+        for trd in trades:
+            if trd.is_buy:
+                trd.amount *= buy_amount_adjusted_rate
             if self.asset_param.EnableCommission:
                 if trd.is_buy:
                     trd.volume = trd.amount / trd.trade_price / (1 + self.asset_param.PurchaseDiscount * self.asset_param.AssetPurchaseRate[trd.index_id])
                     trd.commission = trd.volume * trd.trade_price * self.asset_param.PurchaseDiscount * self.asset_param.AssetPurchaseRate[trd.index_id]
-                else:
-                    trd.commission = trd.amount * self.asset_param.RedeemDiscount * self.asset_param.AssetRedeemRate[trd.index_id]
-                    trd.amount -= trd.commission
             else:
                 trd.commission = 0
             bt_position.update(trd)
@@ -190,11 +212,8 @@ class FundTrader(AssetTrader):
         pendings = []
         traded_list = []
         # TODO: if some trades needs more time
+        # 先成交卖单， 再根据卖单成交金额 等额成交买单
         for trd in trades:
-            if trd.fund_id not in disproved_set:
-                trd.is_permitted_fund = True
-            else:
-                trd.is_permitted_fund = False
             trd.trade_price = cur_fund_nav[trd.fund_id]
             trd.fund_unit_nav = cur_fund_unit_nav[trd.fund_id]
             trd.volume = trd.volume if trd.volume else (trd.amount / trd.trade_price)
@@ -208,15 +227,9 @@ class FundTrader(AssetTrader):
                     assert cur_vol is not None, 'sell fund with no current position!'
                     trd.volume = cur_vol
                     trd.amount = trd.volume * trd.trade_price
+            
             if self.fund_param.EnableCommission:
-                if trd.is_buy:
-                    purchase_fee = fund_purchase_fees[trd.fund_id] * self.fund_param.PurchaseDiscount 
-                    if np.isnan(purchase_fee):
-                        #print(f'fund_id {trd.fund_id} purchase fee data not avaiable')
-                        purchase_fee = 0
-                    trd.volume = trd.amount / trd.trade_price / (1 + purchase_fee)
-                    trd.commission = trd.volume * trd.trade_price * purchase_fee
-                else:
+                if not trd.is_buy:
                     redeem_fee = fund_redeem_fees[trd.fund_id] * self.fund_param.RedeemDiscount
                     if np.isnan(redeem_fee):
                         #print(f'fund_id {trd.fund_id} redeem fee data not avaiable')
@@ -225,16 +238,45 @@ class FundTrader(AssetTrader):
                     trd.amount -= trd.commission
             else:
                 trd.commission = 0
-            if trd.is_permitted_fund == False:
-                pass
+            if not trd.is_buy:
+                trade_status = cur_fund_position.update(trd)
+                if trade_status:
+                    traded_list.append(trd)
+        _trade_list_buy = [i  for i in trades if i.is_buy is True]
+        _trade_list_sel = [i  for i in traded_list if i.is_buy is False]
+        plan_sel_amount = 0 if len(_trade_list_sel) < 1 else sum([i.amount for i in _trade_list_sel])
+        plan_buy_amount = 0 if len(_trade_list_buy) < 1 else sum([i.amount for i in _trade_list_buy])
+        if plan_sel_amount == 0: 
+            buy_amount_adjusted_rate = 1
+        else:
+            buy_amount_adjusted_rate = plan_sel_amount / plan_buy_amount
+        
+        for trd in trades:
+            if not trd.is_buy:
+                continue
+            trd.amount *= buy_amount_adjusted_rate
+            if self.fund_param.EnableCommission:
+                purchase_fee = fund_purchase_fees[trd.fund_id] * self.fund_param.PurchaseDiscount 
+                if np.isnan(purchase_fee):
+                    #print(f'fund_id {trd.fund_id} purchase fee data not avaiable')
+                    purchase_fee = 0
+                trd.volume = trd.amount / trd.trade_price / (1 + purchase_fee)
+                trd.commission = trd.volume * trd.trade_price * purchase_fee
+            else:
+                trd.commission = 0            
                 #print(f'trade is not permitted : {trd}')
-
             trade_status = cur_fund_position.update(trd)
             if trade_status:
                 traded_list.append(trd)
             else:
                 pass
                 #print(f'trade failed alert : {trd}')
+        _trade_list_buy = [i  for i in traded_list if i.is_buy is True]
+        _trade_list_sel = [i  for i in traded_list if i.is_buy is False]
+        # plan_sel_amount = 0 if len(_trade_list_sel) < 1 else sum([i.amount for i in _trade_list_sel])
+        # plan_buy_amount = 0 if len(_trade_list_buy) < 1 else sum([i.amount for i in _trade_list_buy])
+        # print(f'trade date {dt} sell amount {plan_sel_amount} buy amount {plan_buy_amount} diff {plan_buy_amount-plan_sel_amount}')
+
         # get cur asset weight from fund weight
         cur_mv, cur_fund_weight = cur_fund_position.calc_mv_n_w(cur_fund_nav)
         fund_index_dic = {}
@@ -255,7 +297,6 @@ class FundTrader(AssetTrader):
         bt_position.cash = cur_fund_position.cash
         return pendings, traded_list
 
-
     def judge_trade(self, dt, 
             index_fund_cache: list, # to change
             tar_fund_weight: FundWeight,
@@ -399,13 +440,11 @@ class FundTrader(AssetTrader):
 
 
         fund_trades.sort(key=lambda x: x.is_buy)
-
         new_fund_position = cur_fund_position.copy()
 
         for _trade in fund_trades:
             _trade.trigger = trigger
             new_fund_position.update(_trade)
-        
         return new_fund_position, fund_trades, trigger_reason
 
 
@@ -448,15 +487,30 @@ class FundTrader(AssetTrader):
                             submit_date=dt
                         )
                     else:
+                        is_to_clean_up = target_fund_amt == 0 and cur_fund_amt > 0
                         _trade = FundTrade(
                             fund_id=fund_id,
                             index_id=index_id,
                             mark_price=p,
-                            volume=abs(target_fund_amt - cur_fund_amt)/p,
+                            # 如果清仓 在 calc_trade时就把volume 改成全部仓位， 防止小量仓位残留
+                            volume= cur_fund_volume if is_to_clean_up else abs(target_fund_amt - cur_fund_amt)/p,
                             is_buy=is_buy,
                             submit_date=dt,
-                            is_to_cleanup=(target_fund_amt == 0 and cur_fund_amt > 0)
+                            is_to_cleanup=is_to_clean_up
                         )
                     fund_trades.append(_trade)
                     # print(f'(fund){fund_id} (d){"buy" if is_buy else "sell"} (r){c.fund_ranks.get(fund_id, -1)} (p){p} (amt){target_fund_amt - cur_fund_amt} (tar){target_fund_amt} (ind){index_id}')
+        
+        #如果一个交易单过小，不达到交易下限，会被忽略，导致买单和卖单交易额相加不相等
+        buy_trades_amt = sum([i.amount for i in fund_trades if i.is_buy is True])
+        sell_trades_amt = sum([i.mark_price * i.volume for i in fund_trades if i.is_buy is False]) 
+        buy_adjusted = sell_trades_amt / buy_trades_amt if sell_trades_amt > 0 else 1
+        for trd in fund_trades:
+            if trd.is_buy == True:
+                trd.amount *= buy_adjusted
+        
+        ## 检查买卖量是否一致
+        # buy_trades_amt = sum([i.amount for i in fund_trades if i.is_buy is True])
+        # sell_trades_amt = sum([i.mark_price * i.volume for i in fund_trades if i.is_buy is False]) 
+        # print(f'  compare trades dt {dt} amt buy {buy_trades_amt} and sell {sell_trades_amt} diff {buy_trades_amt-sell_trades_amt }')
         return fund_trades
