@@ -72,7 +72,7 @@ class Calculator:
             mdd = 1 - mdd_part.min()
             mdd_date2 = mdd_part.idxmin()
             mdd_date1 = sr[:mdd_date2].idxmax()
-            ret_over_mdd = annualized_ret / mdd
+            ret_over_mdd = annualized_ret / mdd if mdd != 0 else None
             last_mv_diff = sr[-1] - sr[-2]
             last_increase_rate = (sr[-1] - sr[-2])/ sr[-2]
         # 如果只输入一天，返回空
